@@ -158,6 +158,18 @@ extern "C" {
 		const char *who, int stat, const char *msg, int away, int idle,
 		int mobile);
 
+/*
+ * Name: ext_yahoo_got_buzz
+ * 	Called when remote user sends you a buzz.
+ * Params:
+ * 	id   - the id that identifies the server connection
+ * 	me   - the identity the message was sent to
+ * 	who  - the handle of the remote user
+ * 	tm   - timestamp of message if offline
+ */
+	void YAHOO_CALLBACK_TYPE(ext_yahoo_got_buzz) (int id, const char *me,
+		const char *who, long tm);
+
 /*
  * Name: ext_yahoo_got_im
  * 	Called when remote user sends you a message.
